==> ejc-jlprogress-impl-3.0.0-20240507.101713-23-sources.jar: com/ejianc/business/jlprogress/order/bean/OutStoreEntity.java <==
package com.ejianc.business.jlprogress.order.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.jlprogress.order.bean.OutStoreDetailEntity;
/**
 * 订单及运单-材料出库单-主表
 *
 * @author generator
 *
 */
 @TableName("ejc_order_out_store")
public class OutStoreEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="contract_code")
    private String contractCode; // 合同code
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目code
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 组织code
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 父级组织编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织
    @TableField(value="store_org_id")
    private Long storeOrgId; // 领料部门
    @TableField(value="store_org_name")
    private String storeOrgName; // 领料部门名称
    @TableField(value="store_org_code")
    private String storeOrgCode; // 领料部门code
    @TableField(value="wbs_id")
    private Long wbsId; // 构件Id
    @TableField(value="wbs_name")
    private String wbsName; // 构件名称
    @TableField(value="store_date")
    private Date storeDate; // 单据日期
    @TableField(value="store_mny")
    private BigDecimal storeMny; // 出库金额
    @TableField(value="store_id")
    private Long storeId; // 仓库Id
    @TableField(value="store_name")
    private String storeName; // 仓库名称
    @TableField(value="store_employee_id")
    private Long storeEmployeeId; // 库管员
    @TableField(value="store_employee_name")
    private String storeEmployeeName; // 库管员名称
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）


    @TableField(exist=false)
    @SubEntity(serviceName="outStoreDetailService",pidName = "outStoreId")
    private List<OutStoreDetailEntity> outStoreDetailList = new ArrayList<>(); // 订单及运单-材料出库单-子表


    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public Long getStoreOrgId() {
        return storeOrgId;
    }

    public void setStoreOrgId(Long storeOrgId) {
        this.storeOrgId = storeOrgId;
    }
    public String getStoreOrgName() {
        return storeOrgName;
    }

    public void setStoreOrgName(String storeOrgName) {
        this.storeOrgName = storeOrgName;
    }
    public String getStoreOrgCode() {
        return storeOrgCode;
    }

    public void setStoreOrgCode(String storeOrgCode) {
        this.storeOrgCode = storeOrgCode;
    }
    public Long getWbsId() {
        return wbsId;
    }

    public void setWbsId(Long wbsId) {
        this.wbsId = wbsId;
    }
    public String getWbsName() {
        return wbsName;
    }

    public void setWbsName(String wbsName) {
        this.wbsName = wbsName;
    }
    public Date getStoreDate() {
        return storeDate;
    }

    public void setStoreDate(Date storeDate) {
        this.storeDate = storeDate;
    }
    public BigDecimal getStoreMny() {
        return storeMny;
    }

    public void setStoreMny(BigDecimal storeMny) {
        this.storeMny = storeMny;
    }
    public Long getStoreId() {
        return storeId;
    }

    public void setStoreId(Long storeId) {
        this.storeId = storeId;
    }
    public String getStoreName() {
        return storeName;
    }

    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }
    public Long getStoreEmployeeId() {
        return storeEmployeeId;
    }

    public void setStoreEmployeeId(Long storeEmployeeId) {
        this.storeEmployeeId = storeEmployeeId;
    }
    public String getStoreEmployeeName() {
        return storeEmployeeName;
    }

    public void setStoreEmployeeName(String storeEmployeeName) {
        this.storeEmployeeName = storeEmployeeName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }


    public List<OutStoreDetailEntity> getOutStoreDetailList() {
        return outStoreDetailList;
    }

    public void setOutStoreDetailList(List<OutStoreDetailEntity> outStoreDetailList) {
        this.outStoreDetailList = outStoreDetailList;
    }
}

==> ejc-jlprogress-impl-3.0.0-20241016.094058-340-sources.jar: com/ejianc/business/jlprogress/order/bean/OutStoreEntity.java <==
package com.ejianc.business.jlprogress.order.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.jlprogress.order.bean.OutStoreDetailEntity;
/**
 * 订单及运单-材料出库单-主表
 *
 * @author generator
 *
 */
 @TableName("ejc_order_out_store")
public class OutStoreEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="contract_code")
    private String contractCode; // 合同code
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目code
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 组织code
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 父级组织编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织
    @TableField(value="store_org_id")
    private Long storeOrgId; // 领料部门
    @TableField(value="store_org_name")
    private String storeOrgName; // 领料部门名称
    @TableField(value="store_org_code")
    private String storeOrgCode; // 领料部门code
    @TableField(value="wbs_id")
    private Long wbsId; // 构件Id
    @TableField(value="wbs_name")
    private String wbsName; // 构件名称
    @TableField(value="store_date")
    private Date storeDate; // 单据日期
    @TableField(value="store_mny")
    private BigDecimal storeMny; // 出库金额
    @TableField(value="store_id")
    private Long storeId; // 仓库Id
    @TableField(value="store_name")
    private String storeName; // 仓库名称
    @TableField(value="store_employee_id")
    private Long storeEmployeeId; // 库管员
    @TableField(value="store_employee_name")
    private String storeEmployeeName; // 库管员名称
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(exist = false)
    private String billStateName;


    @TableField(exist=false)
    @SubEntity(serviceName="outStoreDetailService",pidName = "outStoreId")
    private List<OutStoreDetailEntity> outStoreDetailList = new ArrayList<>(); // 订单及运单-材料出库单-子表

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public Long getStoreOrgId() {
        return storeOrgId;
    }

    public void setStoreOrgId(Long storeOrgId) {
        this.storeOrgId = storeOrgId;
    }
    public String getStoreOrgName() {
        return storeOrgName;
    }

    public void setStoreOrgName(String storeOrgName) {
        this.storeOrgName = storeOrgName;
    }
    public String getStoreOrgCode() {
        return storeOrgCode;
    }

    public void setStoreOrgCode(String storeOrgCode) {
        this.storeOrgCode = storeOrgCode;
    }
    public Long getWbsId() {
        return wbsId;
    }

    public void setWbsId(Long wbsId) {
        this.wbsId = wbsId;
    }
    public String getWbsName() {
        return wbsName;
    }

    public void setWbsName(String wbsName) {
        this.wbsName = wbsName;
    }
    public Date getStoreDate() {
        return storeDate;
    }

    public void setStoreDate(Date storeDate) {
        this.storeDate = storeDate;
    }
    public BigDecimal getStoreMny() {
        return storeMny;
    }

    public void setStoreMny(BigDecimal storeMny) {
        this.storeMny = storeMny;
    }
    public Long getStoreId() {
        return storeId;
    }

    public void setStoreId(Long storeId) {
        this.storeId = storeId;
    }
    public String getStoreName() {
        return storeName;
    }

    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }
    public Long getStoreEmployeeId() {
        return storeEmployeeId;
    }

    public void setStoreEmployeeId(Long storeEmployeeId) {
        this.storeEmployeeId = storeEmployeeId;
    }
    public String getStoreEmployeeName() {
        return storeEmployeeName;
    }

    public void setStoreEmployeeName(String storeEmployeeName) {
        this.storeEmployeeName = storeEmployeeName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }


    public List<OutStoreDetailEntity> getOutStoreDetailList() {
        return outStoreDetailList;
    }

    public void setOutStoreDetailList(List<OutStoreDetailEntity> outStoreDetailList) {
        this.outStoreDetailList = outStoreDetailList;
    }
}
